==> xiaoerke-common-1.0.103-sources.jar: com/cxqm/xiaoerke/common/web/CKFAliyunGetFoldersCommand.java <==
package com.cxqm.xiaoerke.common.web;
//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by Fernflower decompiler)
//

import com.aliyun.oss.model.ListObjectsRequest;
import com.aliyun.oss.model.OSSObjectSummary;
import com.aliyun.oss.model.ObjectListing;
import com.ckfinder.connector.data.ResourceType;
import com.ckfinder.connector.data.XmlAttribute;
import com.ckfinder.connector.data.XmlElementData;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.handlers.command.XMLCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import com.ckfinder.connector.utils.FileUtils;
import com.ckfinder.connector.utils.NaturalOrderComparator;
import com.cxqm.xiaoerke.common.utils.OSSObjectTool;
import com.cxqm.xiaoerke.modules.sys.security.SystemAuthorizingRealm;
import com.cxqm.xiaoerke.modules.sys.utils.UserUtils;
import org.w3c.dom.Element;

import java.io.File;
import java.util.*;

import com.ckfinder.connector.data.ResourceType;
import com.ckfinder.connector.data.XmlAttribute;
import com.ckfinder.connector.data.XmlElementData;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.handlers.command.XMLCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import com.ckfinder.connector.utils.FileUtils;
import com.ckfinder.connector.utils.NaturalOrderComparator;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.w3c.dom.Element;

import javax.servlet.http.HttpServletRequest;

public class CKFAliyunGetFoldersCommand extends XMLCommand {
	private List<String> directories;

	private String buket_key;

	private String userId;

	public CKFAliyunGetFoldersCommand() {
	}

	protected boolean checkIfCurrFolderExists(HttpServletRequest request) throws ConnectorException {
		return true;
	}

	protected void createXMLChildNodes(int errorNum, Element rootElement) throws ConnectorException {
		if(errorNum == 0) {
			this.createFoldersData(rootElement);
		}

	}

	protected int getDataForXml() {
		SystemAuthorizingRealm.Principal principal = (SystemAuthorizingRealm.Principal) UserUtils.getPrincipal();
		Map<String, ResourceType> types = this.configuration.getTypes();
		String typeName = ((ResourceType) types.get(this.type)).getName();
		directories = OSSObjectTool.getChildFolders(buket_key == null || buket_key.trim().equals("") ? OSSObjectTool.BUCKET_BACKEND_PIC : buket_key, "/"+ userId == null || userId.trim().equals("") ? principal.getId() : userId +"/" + typeName + this.currentFolder);
		return 0;
	}

	private void filterListByHiddenAndNotAllowed() {

	}

	private void createFoldersData(Element rootElement) {
		Element element = this.creator.getDocument().createElement("Folders");
		Iterator i$ = this.directories.iterator();

		while(i$.hasNext()) {
			String dirPath = (String)i$.next();
			XmlElementData xmlElementData = new XmlElementData("Folder");
			xmlElementData.getAttributes().add(new XmlAttribute("name", dirPath));
			xmlElementData.getAttributes().add(new XmlAttribute("hasChildren", "true"));
			xmlElementData.getAttributes().add(new XmlAttribute("acl", "255"));
			xmlElementData.addToDocument(this.creator.getDocument(), element);
		}

		rootElement.appendChild(element);
	}

	public String getBuket_key() {
		return buket_key;
	}

	public void setBuket_key(String buket_key) {
		this.buket_key = buket_key;
	}

	public String getUserId() {
		return userId;
	}

	public void setUserId(String userId) {
		this.userId = userId;
	}
}

==> xiaoerke-common-1.0.109-sources.jar: com/cxqm/xiaoerke/common/web/CKFAliyunGetFoldersCommand.java <==
package com.cxqm.xiaoerke.common.web;
//
// Source code recreated from a .class file by IntelliJ IDEA
// (powered by Fernflower decompiler)
//

import com.aliyun.oss.model.ListObjectsRequest;
import com.aliyun.oss.model.OSSObjectSummary;
import com.aliyun.oss.model.ObjectListing;
import com.ckfinder.connector.data.ResourceType;
import com.ckfinder.connector.data.XmlAttribute;
import com.ckfinder.connector.data.XmlElementData;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.handlers.command.XMLCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import com.ckfinder.connector.utils.FileUtils;
import com.ckfinder.connector.utils.NaturalOrderComparator;
import com.cxqm.xiaoerke.common.filter.CKFAliyunBukert;
import com.cxqm.xiaoerke.common.utils.OSSObjectTool;
import com.cxqm.xiaoerke.modules.sys.security.SystemAuthorizingRealm;
import com.cxqm.xiaoerke.modules.sys.utils.UserUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.w3c.dom.Element;

import java.io.File;
import java.util.*;

import com.ckfinder.connector.data.ResourceType;
import com.ckfinder.connector.data.XmlAttribute;
import com.ckfinder.connector.data.XmlElementData;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.handlers.command.XMLCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import com.ckfinder.connector.utils.FileUtils;
import com.ckfinder.connector.utils.NaturalOrderComparator;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import org.w3c.dom.Element;

import javax.servlet.http.HttpServletRequest;

public class CKFAliyunGetFoldersCommand extends XMLCommand {
	private List<String> directories;

	public CKFAliyunGetFoldersCommand() {
	}

	protected boolean checkIfCurrFolderExists(HttpServletRequest request) throws ConnectorException {
		return true;
	}

	protected void createXMLChildNodes(int errorNum, Element rootElement) throws ConnectorException {
		if(errorNum == 0) {
			this.createFoldersData(rootElement);
		}

	}

	protected int getDataForXml() {
		SystemAuthorizingRealm.Principal principal = (SystemAuthorizingRealm.Principal) UserUtils.getPrincipal();
		String buket_key = CKFAliyunBukert.getBuketKey();
		String userId = CKFAliyunBukert.getUserId();
		Map<String, ResourceType> types = this.configuration.getTypes();
		String typeName = ((ResourceType) types.get(this.type)).getName();
		directories = OSSObjectTool.getChildFolders(buket_key == null || buket_key.trim().equals("") ? OSSObjectTool.BUCKET_BACKEND_PIC : buket_key, "/"+ userId == null || userId.trim().equals("") ? principal.getId() : userId +"/" + typeName + this.currentFolder);
		return 0;
	}

	private void filterListByHiddenAndNotAllowed() {

	}

	private void createFoldersData(Element rootElement) {
		Element element = this.creator.getDocument().createElement("Folders");
		Iterator i$ = this.directories.iterator();

		while(i$.hasNext()) {
			String dirPath = (String)i$.next();
			XmlElementData xmlElementData = new XmlElementData("Folder");
			xmlElementData.getAttributes().add(new XmlAttribute("name", dirPath));
			xmlElementData.getAttributes().add(new XmlAttribute("hasChildren", "true"));
			xmlElementData.getAttributes().add(new XmlAttribute("acl", "255"));
			xmlElementData.addToDocument(this.creator.getDocument(), element);
		}

		rootElement.appendChild(element);
	}
}
